@@ -2,9 +2,16 @@ package builder::MyBuilder;
 use strict;
 use warnings;
 use base qw(Module::Build);
+use Devel::PPPort;
+use File::Spec;
 
 sub new {
     my ( $self, %args ) = @_;
+
+    print "Writing ppport.h\n";
+    Devel::PPPort::WriteFile(
+        File::Spec->catfile(qw/lib Text Sass ppport.h/) );
+
     $self->SUPER::new(
         %args,
         c_source             => ['libsass'],
