@@ -14,13 +14,19 @@
 #include "functions.hpp"
 #endif
 
+#ifndef SASS_VALUES
+#include "sass_values.h"
+#endif
+// struct Sass_C_Function_Data;
+
 namespace Sass {
   using std::pair;
   using std::map;
-  
+
   struct Context {
     Environment global_env;
     map<string, Function> function_env;
+    vector<Sass_C_Function_Data> c_function_list;
     multimap<Node, Node> extensions;
     vector<pair<Node, Node> > pending_extensions;
     vector<const char*> source_refs; // all the source c-strings
@@ -41,8 +47,11 @@ namespace Sass {
 
     void register_function(Signature sig, Primitive ip);
     void register_function(Signature sig, Primitive ip, size_t arity);
+    void register_c_function(Signature sig, C_Function ip);
+    void register_c_function(Signature sig, C_Function ip, size_t arity);
     void register_overload_stub(string name);
     void register_functions();
+    void register_c_functions();
     void setup_color_map();
   };
 
